Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(224)

Unified Diff: remoting/client/plugin/pepper_video_renderer_3d.h

Issue 2690943005: Updating OnPictureReady() method name per CR feedback (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/plugin/pepper_video_renderer_3d.h
diff --git a/remoting/client/plugin/pepper_video_renderer_3d.h b/remoting/client/plugin/pepper_video_renderer_3d.h
index 23494640769be24cc7439b3c29e8c6e7cb8fce91..807019e535ddcd3e2a6bf51b49344f9b1a1d2f38 100644
--- a/remoting/client/plugin/pepper_video_renderer_3d.h
+++ b/remoting/client/plugin/pepper_video_renderer_3d.h
@@ -71,8 +71,8 @@ class PepperVideoRenderer3D : public PepperVideoRenderer,
// Callback for pp::VideoDecoder::Decode().
void OnDecodeDone(int32_t result);
- // Fetches next picture from the |video_decoder_|.
- void GetNextPicture();
+ // Fetches next picture from the |video_decoder_| if a decoded frame is ready.
+ void GetNextPictureIfReady();
// Callback for pp::VideoDecoder::GetPicture().
void OnPictureReady(int32_t result, PP_VideoPicture picture);
« no previous file with comments | « no previous file | remoting/client/plugin/pepper_video_renderer_3d.cc » ('j') | remoting/client/plugin/pepper_video_renderer_3d.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698